;; Generated package description from consult.el  -*- no-byte-compile: t -*-
(define-package "consult" "1.9.0.20250121.142346" "Consulting completing-read" '((emacs "28.1") (compat "30")) :commit "31b5c191f9869aa26bedf35991635e03539a1270" :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("matching" "files" "completion") :url "https://github.com/minad/consult")
